"""Free Google Translate API for Python. Translates totally free of charge."""
# __all__ = 'Translator',
# __version__ = '2.4.0'


# from google_trans.client import Translator
# from google_trans.constants import LANGCODES, LANGUAGES
